@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2021-11-23 18:10:32
+@LastEditTime: 2021-12-08 16:27:23
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -44,7 +44,6 @@ class TaskInfoListHandler(ClientBaseHandler):
         return self.response_json_success(self.business_process_executed(result_list, ref_params))
 
 
-
 class ReceiveRewardHandler(ClientBaseHandler):
     """
     :description: 处理领取任务奖励
@@ -78,7 +77,8 @@ class ReceiveRewardHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
-        invoke_result_data = task_base_model.process_receive_reward(app_id, act_id, module_id, user_id, login_token, task_id, task_sub_type, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat)
+        info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
+        invoke_result_data = task_base_model.process_receive_reward(app_id, act_id, module_id, user_id, login_token, task_id, task_sub_type, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -118,7 +118,8 @@ class FreeGiftHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
-        invoke_result_data = task_base_model.process_free_gift(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat)
+        info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
+        invoke_result_data = task_base_model.process_free_gift(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -154,11 +155,12 @@ class OneSignHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else True
+        check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else False
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
-        invoke_result_data = task_base_model.process_one_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat)
+        info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else {}
+        invoke_result_data = task_base_model.process_one_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -198,7 +200,8 @@ class WeeklySignHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
-        invoke_result_data = task_base_model.process_weekly_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat)
+        info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
+        invoke_result_data = task_base_model.process_weekly_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -238,7 +241,8 @@ class CumulativeSignHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
-        invoke_result_data = task_base_model.process_cumulative_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat)
+        info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
+        invoke_result_data = task_base_model.process_cumulative_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat,info_json)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -319,7 +323,10 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, self.get_param("access_token"), app_key, app_secret, check_user_nick, continue_request_expire)
+        app_base_model = AppBaseModel(context=self)
+        app_info_dict = app_base_model.get_app_info_dict(app_id)
+        access_token = app_info_dict["access_token"] if app_info_dict else ""
+        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, access_token, app_key, app_secret, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -439,7 +446,8 @@ class FavorStoreHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
-        invoke_result_data = task_base_model.process_favor_store(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_user_nick, continue_request_expire, is_stat)
+        info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
+        invoke_result_data = task_base_model.process_favor_store(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_user_nick, continue_request_expire, is_stat, info_json)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -478,7 +486,8 @@ class JoinMemberHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
-        invoke_result_data = task_base_model.process_join_member(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_user_nick, continue_request_expire, is_stat)
+        info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
+        invoke_result_data = task_base_model.process_join_member(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_user_nick, continue_request_expire, is_stat, info_json)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -534,4 +543,3 @@ class BrowseSiteHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
-
