@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2021-12-01 10:32:22
+@LastEditTime: 2021-12-14 10:31:13
 @LastEditors: HuangJianYi
 @Description: 公共handler模块
 """
@@ -110,7 +110,7 @@ class FrameBaseHandler(BaseApiHandler):
 
     def _convert_request_params(self):
         """
-        :Description: 转换请求参数
+        :Description: 转换请求参数 post请求：Content-type必须为application/json，前端必须对对象进行序列化转成json字符串，不能直接传对象,否则无法接收参数
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
@@ -120,7 +120,11 @@ class FrameBaseHandler(BaseApiHandler):
         is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
         if is_encrypt == True and ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
             encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
-            app_id = self.get_argument("source_app_id", "", strip=True)
+            #当有参数app_id时，优先取app_id，然后在是source_app_id
+            if self.get_argument("app_id", "", strip=True):
+                app_id = self.get_argument("app_id", "", strip=True)
+            else:
+                app_id = self.get_argument("source_app_id", "", strip=True)
             if not app_id:
                 app_id = config.get_value("app_id")
             password = str(encrypt_key).replace("1", "l")
@@ -462,6 +466,10 @@ class FrameBaseHandler(BaseApiHandler):
         :return str
         :last_editors: HuangJianYi
         """
+        #当有参数app_id时，优先取app_id，然后在是source_app_id
+        if self.get_param("app_id"):
+            source_app_id = self.get_param("app_id")
+            return source_app_id
         source_app_id = self.get_param("source_app_id")
         #淘宝小程序 在IDE上返回前端模板id，无论哪个环境；在千牛端上返回正确的小程序id
         if source_app_id == config.get_value("client_template_id"):
