@@ -2,9 +2,9 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-11-19 09:58:19
+@LastEditTime: 2021-11-29 16:38:29
 @LastEditors: HuangJianYi
-@Description: 
+@Description: 活动模块
 """
 from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.handlers.frame_base import *
@@ -72,6 +72,8 @@ class AddActInfoHandler(ClientBaseHandler):
         self.create_operation_log(OperationType.add.value, "act_info_tb", "AddActInfoHandler", None, self.json_dumps(invoke_result_data.data))
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data.id)
 
 
@@ -130,6 +132,7 @@ class UpdateActInfoHandler(ClientBaseHandler):
         join_ways = int(self.get_param("join_ways", -1))
         is_fictitious = int(self.get_param("is_fictitious", -1))
         close_word = self.get_param("close_word", None)
+        is_visit_store = int(self.get_param("is_visit_store", -1))
         store_url = self.get_param("store_url", None)
         i1 = int(self.get_param("i1", -1))
         i2 = int(self.get_param("i2", -1))
@@ -148,12 +151,14 @@ class UpdateActInfoHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         act_base_model = ActBaseModel(context=self)
-        invoke_result_data = act_base_model.update_act_info(app_id, act_id, act_name, theme_id, is_share, share_desc_json, is_rule, rule_desc_json, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, close_word, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2)
+        invoke_result_data = act_base_model.update_act_info(app_id, act_id, act_name, theme_id, is_share, share_desc_json, is_rule, rule_desc_json, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, close_word, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, is_visit_store)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.update.value, "act_info_tb", "UpdateActInfoHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]))
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
 
