@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2021-11-29 16:40:55
+@LastEditTime: 2021-12-02 17:58:45
 @LastEditors: HuangJianYi
 @Description: 用户模块
 """
@@ -259,7 +259,6 @@ class UpdateUserAssetHandler(ClientBaseHandler):
         return self.response_json_success()
 
 
-
 class BatchUpdateUserAssetHandler(ClientBaseHandler):
     """
     :description: 批量变更资产
@@ -301,6 +300,33 @@ class BatchUpdateUserAssetHandler(ClientBaseHandler):
         return self.response_json_success()
 
 
+class UserAssetListHandler(ClientBaseHandler):
+    """
+    :description: 获取用户资产列表
+    """
+    @filter_check_params("act_id,tb_user_id")
+    def get_async(self):
+        """
+        :description: 获取用户资产列表
+        :param act_id：活动标识
+        :param tb_user_id：用户标识
+        :param asset_type：资产类型(1-次数2-积分3-价格档位)
+        :return list
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_app_id()
+        act_id = int(self.get_param("act_id", 0))
+        user_id = self.get_user_id()
+        asset_type = int(self.get_param("asset_type", 0))
+
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success({"data": []})
+        asset_base_model = AssetBaseModel(context=self)
+        ref_params = {}
+        return self.response_json_success(self.business_process_executed(asset_base_model.get_user_asset_list(app_id, act_id, user_id, asset_type), ref_params))
+
+
 class AssetLogListHandler(ClientBaseHandler):
     """
     :description: 资产流水记录
@@ -339,8 +365,17 @@ class AssetLogListHandler(ClientBaseHandler):
         asset_type = int(self.get_param("asset_type", 0))
         asset_object_id = self.get_param("asset_object_id")
 
+        field = "*"
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success({"data": []})
+        else:
+            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         asset_base_model = AssetBaseModel(context=self)
-        return self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id,"*",is_cache=False))
+        page_info = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id, field, is_cache=False)
+        ref_params = {}
+        page_info.data = self.business_process_executed(page_info.data, ref_params)
+        return self.response_json_success(page_info)
 
 
 class UserInfoListHandler(ClientBaseHandler):
@@ -376,4 +411,4 @@ class UserInfoListHandler(ClientBaseHandler):
         user_base_model = UserBaseModel(context=self)
         page_info = user_base_model.get_user_list(app_id, act_id, page_size, page_index, user_state, user_id, start_date, end_date, user_nick, open_id)
         ref_params = {}
-        return self.reponse_json_success(self.business_process_executed(page_info, ref_params))
\ No newline at end of file
+        return self.response_json_success(self.business_process_executed(page_info, ref_params))
\ No newline at end of file
