@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-30 09:22:51
-@LastEditTime: 2021-10-13 19:03:19
+@LastEditTime: 2021-11-04 10:13:10
 @LastEditors: HuangJianYi
 @Description: 排队系统帮助类
 """
@@ -13,8 +13,9 @@ from seven_cloudapp_frame.libs.customize.seven_helper import *
 
 class QueueUpHelper:
     """
-    :description: 排队系统帮助类 提供获取小程序总排队人数、获取用户当前排队数、获取用户正在办理中的队列信息、加入排队、退出排队、查询单个排队情况、批量查询某用户排队情况(只包含已排队的信息)、批量查询某用户排队情况(包含已排队和未排队的信息)、更新可操作时间、签到等功能
-    踢人规则：第一个在办理中，第二个用户的过期时间=第一个结束时间+8*1，第三个=第一个结束时间+8*2，以此类推；第一个没在办理中，第一个过期时间是8*1，第二个是8*2，第三个是8*3，以此类推；
+    :description: 排队系统帮助类 提供获取小程序总排队人数、获取用户当前排队数、获取用户正在办理中的队列信息、加入排队、退出排队、查询单个排队情况、批量查询某用户排队情况(只包含已排队的信息)、批量查询某用户排队情况(包含已排队和未排队的信息)、更新可操作时间、签到等功能；
+    踢人规则1：第一个在办理中，第二个用户的过期时间=第一个结束时间+8*1，第三个=第一个结束时间+8*2，以此类推；第一个没在办理中，第一个过期时间是8*1，第二个是8*2，第三个是8*3，以此类推；
+    踢人规则2：如果都没有正在办理中，那么取上次办理人退出的时间作为排在第一位人员的开始时间，进行倒计时，没有上次办理人退出时间的话，则取当前第一位人员的入队时间进行倒计时；
     """
     logger_error = Logger.get_logger_by_name("log_error")
 
@@ -163,13 +164,14 @@ class QueueUpHelper:
             return process_queue
 
     @classmethod
-    def queue(self, app_id, queue_name, user_id, user_nick="", queue_length=10, app_limit_user_num=500, info_dict={}):
+    def queue(self, app_id, queue_name, user_id, user_nick="", avatar="", queue_length=10, app_limit_user_num=500, info_dict={}):
         """
         :description: 加入排队
         :param app_id：应用标识
         :param queue_name：队列名称
         :param user_id 用户标识
         :param user_nick 用户昵称
+        :param avatar 头像
         :param queue_length：队列的长度
         :param app_limit_user_num：小程序内总排队人数上限
         :param info_dict：信息字典,用于存储业务端需要的数据
@@ -221,6 +223,7 @@ class QueueUpHelper:
                 hash_value["queue_no"] = queue_no  #排队号
                 hash_value["user_id"] = data  #用户标识
                 hash_value["user_nick"] = user_nick  #用户昵称
+                hash_value["avatar"] = avatar  #头像
                 hash_value["progress_status"] = 1  #进度0未排队1已排队2办理中
                 hash_value["queue_timestamp"] = start_timestamp  #入队时间搓
                 hash_value["queue_date"] = TimeHelper.timestamp_to_format_time(start_timestamp)  #入队时间
@@ -371,7 +374,7 @@ class QueueUpHelper:
                                     pop_timestamp = hash_value["queue_timestamp"]
                                 if now_timestamp > pop_timestamp + ((i + 1) * int(config.get_value("queue_confirm_time", 8))):
                                     is_delete = True
-                                    
+
                         if is_delete == True:
                             self._set_last_pop_date(app_id, redis_init, zset_name)
                             redis_init.hdel(hash_name, f"userid_{data}_queuename_{queue_name}")
@@ -423,15 +426,19 @@ class QueueUpHelper:
 
             #判断是否存在排队信息
             score = redis_init.zscore(zset_name, data)
-            if score:
+            index = redis_init.zrank(zset_name, data)
+            if score and index is not None:
                 query_user = {}
                 query_user["queue_name"] = queue_name  #队列名称
                 query_user["queue_no"] = int(score)  #排队号
                 query_user["total_num"] = self._get_queue_num(app_id, queue_name)  #总排队人数
-                query_user["queue_index"] = int(redis_init.zrank(zset_name, data)) + 1  #当前位置
+                query_user["queue_index"] = int(index) + 1  #当前位置
                 query_user["before_num"] = query_user["queue_index"] - 1  #排在前面的人数
                 hash_value = redis_init.hget(self._get_user_hash_name(app_id), f"userid_{data}_queuename_{queue_name}")
                 hash_value = SevenHelper.json_loads(hash_value) if hash_value else {}
+                query_user["user_id"] = hash_value["user_id"] if hash_value.__contains__("user_id") else ''
+                query_user["user_nick"] = hash_value["user_nick"] if hash_value.__contains__("user_nick") else ''
+                query_user["avatar"] = hash_value["avatar"] if hash_value.__contains__("avatar") else ''
                 query_user["start_date"] = hash_value["start_date"] if hash_value.__contains__("start_date") else ''
                 query_user["end_date"] = hash_value["end_date"] if hash_value.__contains__("end_date") else ''
                 query_user["queue_date"] = hash_value["queue_date"] if hash_value.__contains__("queue_date") else ''
@@ -457,6 +464,28 @@ class QueueUpHelper:
             invoke_result_data.error_message = "未查到排队情况,请先排队"
             return invoke_result_data
 
+    @classmethod
+    def query_all(self, app_id, queue_name):
+        """
+        :description: 查询指定队列的所有用户信息
+        :param app_id：应用标识
+        :param queue_name：队列名称
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = []
+        zset_name = self._get_zset_name(app_id, queue_name)
+        redis_init = SevenHelper.redis_init()
+        user_id_list = redis_init.zrange(zset_name,0,-1)
+        if len(user_id_list) <= 0:
+            return invoke_result_data
+        for user_id in user_id_list:
+            query_invoke_result_data = self.query(app_id, queue_name, user_id)
+            if query_invoke_result_data.success == True:
+                invoke_result_data.data.append(query_invoke_result_data.data)
+        return invoke_result_data
+
     @classmethod
     def muti_user_query(self, app_id, user_id):
         """
@@ -511,13 +540,14 @@ class QueueUpHelper:
             return invoke_result_data
 
     @classmethod
-    def update_time(self, app_id, queue_name, user_id, operate_time=0):
+    def update_time(self, app_id, queue_name, user_id, operate_time=0,is_reset=False):
         """
         :description: 更新可操作时间，用于操作倒计时，时间到则踢出队列
         :param app_id：应用标识
         :param queue_name：队列名称
         :param user_id：用户标识
         :param operate_time：增加的操作时间，单位秒
+        :param is_reset：是否重置开始时间和结束时间
         :return: 
         :last_editors: HuangJianYi
         """
@@ -542,9 +572,17 @@ class QueueUpHelper:
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = "未签到,不能更新可操作时间"
                     return invoke_result_data
-                end_timestamp = TimeHelper.get_now_timestamp() + int(operate_time)
-                hash_value["end_timestamp"] = end_timestamp
-                hash_value["end_date"] = TimeHelper.timestamp_to_format_time(end_timestamp)
+                if is_reset == True:
+                    start_timestamp = TimeHelper.get_now_timestamp()
+                    hash_value["start_timestamp"] = start_timestamp
+                    hash_value["start_date"] = TimeHelper.timestamp_to_format_time(start_timestamp)
+                    end_timestamp = start_timestamp + int(operate_time)
+                    hash_value["end_timestamp"] = end_timestamp
+                    hash_value["end_date"] = TimeHelper.timestamp_to_format_time(end_timestamp)
+                else:
+                    end_timestamp = hash_value["end_timestamp"] + int(operate_time)
+                    hash_value["end_timestamp"] = end_timestamp
+                    hash_value["end_date"] = TimeHelper.timestamp_to_format_time(end_timestamp)
                 redis_init.hset(hash_name, hash_key, SevenHelper.json_dumps(hash_value))
             return invoke_result_data
         except Exception as ex:
