@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-12-01 10:19:40
+@LastEditTime: 2021-12-06 17:43:49
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -128,23 +128,22 @@ class SevenHelper:
         lock = "lock:" + lock_name
         redis_init = self.redis_init()
         pip = redis_init.pipeline(True)
-        while True:
-            try:
-                pip.watch(lock)
-                lock_value = redis_init.get(lock)
-                if not lock_value:
-                    return True
-                if lock_value == identifier:
-                    pip.multi()
-                    pip.delete(lock)
-                    pip.execute()
-                    return True
-                pip.unwatch()
-                break
-            except Exception:
-                pass
-        return False
-
+        try:
+            pip.watch(lock)
+            lock_value = redis_init.get(lock)
+            if not lock_value:
+                return True
+            if lock_value == identifier:
+                pip.multi()
+                pip.delete(lock)
+                pip.execute()
+                return True
+            pip.unwatch()
+            return False
+        except Exception:
+            pip.unwatch()
+            return False
+            
     @classmethod
     def merge_dict_list(self, source_dict_list, source_key, merge_dict_list, merge_key, merge_columns_names='', exclude_merge_columns_names=''):
         """
