@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2021-11-25 10:59:56
+@LastEditTime: 2021-11-30 17:10:08
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -145,7 +145,8 @@ class AppBaseModel():
         data["renew_info"] = renew_info
 
         product_price_model = ProductPriceModel(context=self.context)
-        product_price = product_price_model.get_cache_entity(where="%s>=begin_time and %s<=end_time and is_release=1",order_by="create_time desc",params=[SevenHelper.get_now_datetime()])
+        now_date = SevenHelper.get_now_datetime()
+        product_price = product_price_model.get_cache_entity(where="%s>=begin_time and %s<=end_time and is_release=1",order_by="create_time desc",params=[now_date,now_date])
         base_info = {}
         # 把string转成数组对象
         base_info["update_function"] = SevenHelper.json_loads(base_info_dict["update_function"]) if base_info_dict["update_function"] else []
