@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-12-02 20:20:03
+@LastEditTime: 2021-12-03 11:01:25
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -517,20 +517,20 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
         user_black_model = UserBlackModel(context=self.context)
-        black_info = user_black_model.get_entity_by_id(black_id)
-        if not black_info:
+        user_black = user_black_model.get_entity_by_id(black_id)
+        if not user_black:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "找不到该条记录"
             return invoke_result_data
-        if black_info.app_id != app_id:
+        if user_black.app_id != app_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
             return invoke_result_data
             
         user_info_model = UserInfoModel(context=self.context)
-        id_md5 = self._get_user_info_id_md5(black_info.act_id, black_info.user_id)
+        id_md5 = self._get_user_info_id_md5(user_black.act_id, user_black.user_id)
         user_info = user_info_model.get_entity("id_md5=%s",params=[id_md5])
         if not user_info:
             invoke_result_data.success = False
@@ -561,7 +561,7 @@ class UserBaseModel(FrameBaseModel):
          
         invoke_result_data.data = {"user_info":user_info.__dict__}
         self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
-        self._delete_user_black_cache(black_info.act_id, black_info.user_id)
+        self._delete_user_black_cache(user_black.act_id, user_black.user_id)
         return invoke_result_data
 
     def update_audit_remark(self,app_id,black_id,audit_remark):
