@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-11-26 13:59:49
+@LastEditTime: 2021-12-02 20:21:38
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -23,6 +23,7 @@ def seven_cloudapp_frame_route():
         (r"/client/update_user_info", user.UpdateUserInfoHandler),  #更新用户信息如昵称、头像等
         (r"/client/check_is_member", user.CheckIsMemberHandler),  #校验是否是店铺会员
         (r"/client/apply_black_unbind", user.ApplyBlackUnbindHandler),  #申请黑名单解封
+        (r"/client/get_unbind_apply", user.GetUnbindApplyHandler),  #获取黑名单解封申请记录
         (r"/client/user_asset_list", user.UserAssetListHandler),  #用户资产列表
         (r"/client/asset_log_list", user.AssetLogListHandler),  #用户资产流水列表
         (r"/client/get_join_member_url", user.GetJoinMemberUrlHandler),  #加入会员地址
@@ -121,6 +122,7 @@ def seven_cloudapp_frame_route():
         (r"/server/user_black_list", user_s.UserBlackListHandler),  #黑名单列表
         (r"/server/update_user_asset", user_s.UpdateUserAssetHandler),  #更新用户资产值
         (r"/server/batch_update_user_asset", user_s.BatchUpdateUserAssetHandler),  #批量更新用户资产值
+        (r"/server/user_asset_list", user_s.UserAssetListHandler),  #用户资产列表
         (r"/server/asset_log_list", user_s.AssetLogListHandler),  #资产流水列表
         (r"/server/init_launch_goods", launch_s.ResetLaunchGoodsHandler),  #重置商品投放 删除已投放的记录并将活动投放状态改为未投放
         (r"/server/init_launch_goods", launch_s.InitLaunchGoodsHandler),  #初始化投放商品
